@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: updateprefs.php,v 1.22 2004/09/22 08:11:50 yeupou Exp $
+# $Id: updateprefs.php,v 1.23 2004/09/29 12:54:38 yeupou Exp $
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
 # 
@@ -39,8 +39,7 @@ else
 db_query("UPDATE user SET "
 	 . "mail_siteupdates='1'," # deprecated
 	 . "email_hide=" . ($form_mail_hide?"1":"0") . ","
-	 . "theme='" . $user_theme . "',"
-	 . "use_cvsadmin=" . ($form_use_cvsadmin?"1":"0") . " WHERE "
+	 . "theme='" . $user_theme . "' WHERE "
 	 . "user_id=" . user_getid());
 
 session_redirect($GLOBALS['sys_home'] . "account/");
