@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.8 2004/06/28 14:21:32 yeupou Exp $
+# $Id: general.php,v 1.9 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Stphane Urbanovski <s.urbanovski@ac-nancy-metz.fr>
 #                          Mathieu Roy <yeupou--at--gnu.org>
@@ -22,11 +22,12 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
-function search_box ($searched_words='', $only_artifact=0, $size=15)
+function search_box ($searched_words='', $only_artifact=0, $size=15, $class="")
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':search_box ';
   global $words,$forum_id,$group_id,$is_bug_page,$exact,$type_of_search,$type,$max_rows,$printer;
 
+
   # if there is no search currently, set the default
   if (!isset($type_of_search))
     { $exact = 1; }
@@ -38,59 +39,63 @@ function search_box ($searched_words='', $only_artifact=0, $size=15)
   if ($words == "%%%")
     { $words = "*"; }
 
-  print '<form action="'.$GLOBALS['sys_home'].'search/" method="get" >';
-  print '<input type="text" size="'.$size.'" name="words" value="'.$searched_words.'">';
+  if ($class) 
+    { $class = ' class="'.$class.'"'; }
+
+  print '      <form action="'.$GLOBALS['sys_home'].'search/" method="get" '.$class.'>';
+
+  print '<input type="text" size="'.$size.'" name="words" value="'.$searched_words.'" />';
 
   if ($size < 16)
-    { print '<br>'; }
+    { print '<br />'; }
 
   if ($only_artifact)
     {
-      print '<input type="hidden" name="type_of_search" value="'.$only_artifact.'">';
+      print '<input type="hidden" name="type_of_search" value="'.$only_artifact.'" />';
     }
   else
     {
       print ' '._("in").' <select name="type_of_search">';
 
-      print '<option value="soft"'.(($type_of_search == "soft")||($type_of_search == "") ? " selected" : "").'>'._("Project/Group")."</option>\n";
+      print '<option value="soft"'.(($type_of_search == "soft")||($type_of_search == "") ? ' selected="selected"' : "").'>'._("Project/Group")."</option>\n";
 
-      print '<option value="people"'.(($type_of_search == "people") ? " selected" : "").'>'._("People")."</option>\n";
+      print '<option value="people"'.(($type_of_search == "people") ? ' selected="selected"' : "").'>'._("People")."</option>\n";
 
-      print '<option value="support"'.(($type_of_search == "support") ? " selected" : "").'>'._("Support")."</option>\n";
+      print '<option value="support"'.(($type_of_search == "support") ? ' selected="selected"' : "").'>'._("Support")."</option>\n";
 
-      print '<option value="bugs"'.(($type_of_search == "bugs") ? " selected" : "").'>'._("Bugs")."</option>\n";
+      print '<option value="bugs"'.(($type_of_search == "bugs") ? ' selected="selected"' : "").'>'._("Bugs")."</option>\n";
 
-      print '<option value="task"'.(($type_of_search == "task") ? " selected" : "").'>'._("Task")."</option>\n";
+      print '<option value="task"'.(($type_of_search == "task") ? ' selected="selected"' : "").'>'._("Task")."</option>\n";
 
-      print '<option value="patch"'.(($type_of_search == "patch") ? " selected" : "").'>'._("Patch")."</option>\n";
+      print '<option value="patch"'.(($type_of_search == "patch") ? ' selected="selected"' : "").'>'._("Patch")."</option>\n";
 
       if ($GLOBALS['sys_use_google'])
 	{
-	  print '<option value="google"'.(($type_of_search == "google") ? " selected" : "").' class="italic">'._("via Google")."</option>\n";
+	  print '<option value="google"'.(($type_of_search == "google") ? ' selected="selected"' : "").' class="italic">'._("via Google")."</option>\n";
 	}
 
       print '</select>';
 
     }
   if ($size < 16)
-    { print '<br>'; }
+    { print '<br />'; }
 
   if (isset($group_id))
     {
-      print "<input type=\"hidden\" value=\"$group_id\" name=\"group_id\">\n";
+      print "<input type=\"hidden\" value=\"$group_id\" name=\"group_id\" />\n";
     }
   if (isset($printer))
     {
-      print "<input type=\"hidden\" value=\"1\" name=\"printer\">\n";
+      print "<input type=\"hidden\" value=\"1\" name=\"printer\" />\n";
     }
 
-  print ' <input type="submit" name="Search" value="'._("Search").'">';
+  print ' <input type="submit" name="Search" value="'._("Search").'" />';
 
   if ($size > 15)
     {
-      print '<br />&nbsp;<input type="radio" name="exact" value="0"'.( $exact ? " " : " checked").'>'._("with at least one of the words")."\n";
-      print '<br />&nbsp;<input type="radio" name="exact" value="1"'.( $exact ? " checked" : " " ).'>'._("with all of the words")."\n";
-      print '<br />&nbsp;'.sprintf(_("%s results per page"), '<input type="text" name="max_rows" value="'.$max_rows.'" size="4">')."\n";
+      print '<br />&nbsp;<input type="radio" name="exact" value="0"'.( $exact ? " " : " checked").' />'._("with at least one of the words")."\n";
+      print '<br />&nbsp;<input type="radio" name="exact" value="1"'.( $exact ? " checked" : " " ).' />'._("with all of the words")."\n";
+      print '<br />&nbsp;'.sprintf(_("%s results per page"), '<input type="text" name="max_rows" value="'.$max_rows.'" size="4" />')."\n";
 
       # add the functionality to restrict the search to a project type
       print "<br />&nbsp;";
@@ -109,10 +114,11 @@ function search_box ($searched_words='', $only_artifact=0, $size=15)
     }
   else
     {
-      print '<input type="hidden" name="exact" value="1">';
+      print '<input type="hidden" name="exact" value="1" />';
     }
 
-  print '</form>';
+  if (!$dontclose) 
+    { print '      </form>'; }
 }
 
 function search_send_header ()
@@ -154,7 +160,7 @@ function search_send_header ()
   search_box($words, '', 45);
   print '</div>';
 
-  print '<br>';
+  print '<br />';
   # Print the result
   print '<h3>';
   if ($words && $type_of_search)
@@ -190,7 +196,7 @@ function search_send_header ()
 
   if (!$printer)
     {
-      print '<p><a href="'.$GLOBALS['REQUEST_URI'].'&amp;printer=1"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/print.png" border="0">'._('Printer version').'</a></p>';
+      print '<p><a href="'.$GLOBALS['REQUEST_URI'].'&amp;printer=1"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/print.png" border="0" />'._('Printer version').'</a></p>';
     }
 }
 
