@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: detail.php,v 1.31 2004/06/28 14:21:32 yeupou Exp $
+# $Id: detail.php,v 1.32 2004/09/22 08:11:51 yeupou Exp $
 #
-# Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
 #  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#                          Yves Perrin <yves.perrin--at--cern.ch>
 #
 #
 # This program is free software; you can redistribute it and/or
@@ -41,6 +42,8 @@ if (db_numrows($result) > 0)
     { $item_name = "bug #".$item_id; }
   else
     { $item_name = ARTIFACT." #".$item_id; }
+  # Defines the item link
+  $item_link = utils_link("?func=detailitem&item_id=".$item_id, $item_name);
 
   # Check whether this item is private or not. If it is private, show only to 
   # the submitter
@@ -61,7 +64,7 @@ if (db_numrows($result) > 0)
 
   print $private_intro;
 
-  print '<h2>'.sprintf(_("<i>%s</i> overview:"), $item_name).' '.db_result($result,0,'summary').'</h2>';
+  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
 
   print '<form action="'.$PHP_SELF.'" method="post" enctype="multipart/form-data">';
  
@@ -90,6 +93,12 @@ if (db_numrows($result) > 0)
       if ( (!trackers_data_is_special($field_name)  || $field_name=='summary' || $field_name=='details') &&
 	   trackers_data_is_used($field_name) ) 
 	{
+
+	  # if the submitter was anonymous, print the originator email field
+	  if ($field_name != 'originator_email' ||
+	      ($field_name == 'originator_email' && db_result($result,0,'submitted_by') == '100'))
+	    {
+
 				   
 	  # display the bug field
 	  # if field size is greatest than max_size chars then force it to
@@ -115,7 +124,8 @@ if (db_numrows($result) > 0)
 	      $i++;
 	      print ($i % $fields_per_line ? '':"\n</tr>");
 	    }
-	}
+	}  
+        }
     }
       
   print '</table>';
@@ -123,11 +133,12 @@ if (db_numrows($result) > 0)
 
   # ################################ Shortcuts
 
-  print '<h2>'.sprintf(_("<i>%s</i> details:"), $item_name).'</h2>';
-  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br>';  
-  print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br>';
-  print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br>';
-  print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br>';
+  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> details:"), $item_link).'</h2>';
+  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';  
+  print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br />';
+  print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br />';
+  print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br />';
+  print '&nbsp;&nbsp;- <a href="#history">'._("History").'</a><br />';
   print '<p>&nbsp;</p>';
 
 
@@ -145,9 +156,9 @@ if (db_numrows($result) > 0)
 
   if (!user_isloggedin()) 
     {
-      print '<p><h2 class="warn">'._("You Are NOT Logged In").'</h2><p>';
-      printf (_("Please %slog in,%s so followups can be emailed to you."),'<a href="'.$GLOBALS['sys_home'].'account/login.php?return_to='.urlencode($REQUEST_URI).'">','</a>');
-      print '</font></b><p>';
+      print '<h2 class="warn">'._("You are not logged in").'</h2><p>';
+      printf (_("Please %slog in,%s so followups can be emailed to you."),'<a href="'.$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($REQUEST_URI).'">','</a>');
+      print '</p>';
     }
 
   print '<p>&nbsp;</p>';
@@ -160,10 +171,10 @@ if (db_numrows($result) > 0)
 
   print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
   
-  print '<font class="preinput"> '._("Attach File:").'</font><br>
+  print '<font class="preinput"> '._("Attach File:").'</font><br />
       &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
-      <br>
-      <font class="preinput">'._("File Description:").'</font><br>
+      <br />
+      <font class="preinput">'._("File Description:").'</font><br />
       &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
       </p><p>';
 	  
@@ -179,8 +190,8 @@ if (db_numrows($result) > 0)
     {
       printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
       print '<p>
-	   <font class="preinput">'._("Add an email address that should receive carbon copies of updates of this item:").'</font><br>&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="30"><br>
-	   <font class="preinput">'._("Comment:").'</font><br>&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255"><p>';
+	   <font class="preinput">'._("Add an email address that should receive carbon copies of updates of this item:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="30"><br />
+	   <font class="preinput">'._("Comment:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255"><p>';
     }
 
   show_item_cc_list($item_id, $group_id);
