@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.30 2004/06/30 12:13:30 yeupou Exp $
+# $Id: index.php,v 1.31 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -161,7 +161,7 @@ if ($group_id)
 		if ($reassign_change_project_search)
 		  {
 		    if ($feedback)
-		      { '<br>'; }
+		      { '<br />'; }
 		    fb(_("You provided search words to get a list of project this item should maybe reassigned to. Below, in the section \"Reassign this item\", you can now select the appropriate project and submit the form."));
 		  }
 
@@ -173,7 +173,7 @@ if ($group_id)
 	    $vfl = trackers_extract_field_list();
 
 	    #data control layer
-	    $additional_addresses = "";
+	    $address = "";
 	    $changed = trackers_data_handle_update($group_id,
 						   $item_id,
 						   $dependent_on_task,
@@ -183,7 +183,7 @@ if ($group_id)
 						   $canned_response,
 						   $vfl,
 						   $changes,
-						   $additional_addresses);
+						   $address);
 
 
 	    # Attach new file if there is one
@@ -212,17 +212,14 @@ if ($group_id)
 	    if ($changed)
 	      {
 		# Check if we're supposed to send all modifications to an address
-		list($address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
-		if ($sendall == 1)
-		  {
-	          if (trim($additional_addresses) != "")
-		    {
-                      $address .= ", ".$additional_addresses;
-		    }
-		    trackers_mail_followup($item_id, $address,$changes);
-		  }
+		list($additional_address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
 
-	      }
+                if (($sendall == 1) && (trim($address) != "") && (trim($additional_address) != "")) {
+                  $address .= ", ";
+                }
+                $address .= $additional_address;
+                trackers_mail_followup($item_id, $address,$changes);
+              }
 
 	    # Finally handle reassignation of an entry. Why so late?
 	    # Because all the information entered by someone reassigning
@@ -277,21 +274,21 @@ if ($group_id)
 	# Attach new file if there is one
 	if ($input_file != "none" && $input_file)
 	  {
-	    trackers_attach_file($item_id,
-				 $group_id,
-				 $input_file,
-				 $input_file_name,
-				 $input_file_type,
-				 $input_file_size,
-				 $file_description);
+	    $changed |= trackers_attach_file($item_id,
+			  	             $group_id,
+				             $input_file,
+				             $input_file_name,
+				             $input_file_type,
+				             $input_file_size,
+				             $file_description);
 	  }
 	    # Add new cc if any, only accepted from logged in users.
 	if ($add_cc && user_isloggedin())
 	  {
-	    trackers_add_cc($item_id,
-			    $group_id,
-			    $add_cc,
-			    $cc_comment);
+	    $changed |= trackers_add_cc($item_id,
+			                $group_id,
+			                $add_cc,
+			                $cc_comment);
 	  }
 
 	list($address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
