@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.73 2004/03/26 17:51:49 yeupou Exp $
+# $Id: index.php,v 1.74 2004/06/23 19:46:15 beuc Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -408,7 +408,7 @@ if ($group_id && user_ismember($group_id,'A'))
       # Note: I did not checked that part of the code, that should remain
       # unchanged. Hope it will still work.
       # yeupou@gnu.org 2003-09-24
-      mail_header(array('title'=>'Migrate Mailing Lists'));
+      site_project_header(array('title'=>_("Migrate Mailing Lists"),'group'=>$group_id,'toptab'=>'amail'));
 
       if ($isgnu == false)
 	{
