@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: groups.php,v 1.9 2004/06/25 09:47:54 yeupou Exp $
+# $Id: groups.php,v 1.10 2004/09/22 08:11:51 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Frederik Orellana <frederik.orellana@cern.ch>
 #                          Mathieu Roy <yeupou--at--gnu.org>
@@ -59,9 +59,10 @@ function send_pending_user_email($group_id, $user_id, $user_message)
     }
 
   # send one email per admin, in one command line coma separated
+  $admin_list = '';
   while ($row_admins = db_fetch_array($res_admins))
     {
-      $admin_list .= ','.$row_admins['email'];
+      $admin_list .= ($admin_list ? ',':'').$row_admins['email'];
     }
 
   $message = approval_user_gen_email($row_grp['group_name'],
@@ -141,16 +142,7 @@ site_user_header(array('toptab'=>'mygroups'));
 
 # we get site-specific content
 utils_get_content("account/change_groups_intro");
-
-
-
-print '<table width="100%" border="0"><tr><td valign="top" width="50%">';
-
-/*
-
-PROJECT LIST
-
-*/
+print "<br /><br />\n\n";
 
 $result = db_query("SELECT groups.group_name,"
 		   . "groups.group_id,"
@@ -163,120 +155,29 @@ $result = db_query("SELECT groups.group_name,"
 		   . "AND groups.status='A'");
 $rows=db_numrows($result);
 
-if (!$result || $rows < 1)
-{
 
-  print $HTML->box1_top(_("My Groups"));
-  print _("You're not a member of any public projects");
-  print $HTML->box1_bottom();
+################ RIGHT PART ###########################
 
-}
-else
-{
+print html_splitpage(1);
 
-  /*
-     Projects administrated by the user
-  */
+print $HTML->box_top(_("Request for Inclusion"),'',1);
 
-  print $HTML->box1_top(_("Groups I'm Administrator of"));
-
-  print '<table>';
-  $j;
-  for ($i=0; $i<$rows; $i++)
-    {
-      if (db_result($result,$i,'admin_flags') == 'A')
-	{
-	  print '
-			       <tr class="'.utils_get_alt_row_color($j).'"><td width="99%">'.
-	    '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/"><b>'.
-	    db_result($result,$i,'group_name') .'</b></a>';
-
-	  print '</td>'.
-	    '<td><a href="../my/rmproject.php?group_id='. db_result($result,$i,'group_id').
-	    '" onClick="return confirm(\''._("Quit this project?").'\')">'.
-	    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="remove"></a></td></tr>';
-	  $exists=1;
-	  $j++;
-	}
-    }
-  print '</table>';
-
-
-  if (!$exists)
-    {
-      print _("You're not administrator of any projects");
-    }
-  unset($exists);
-
-  print $HTML->box1_bottom();
-  print "<br><br>";
-
-
-  /*
-     Projects the user is member of
-  */
-
-  print $HTML->box1_top(_("Groups I'm Contributor of"));
-
-  print '<table>';
-  $j = 0;
-  for ($i=0; $i<$rows; $i++)
-    {
-      if (db_result($result,$i,'admin_flags') == '')
-	{
-	  print '
-			       <tr class="'.utils_get_alt_row_color($j).'"><td width="99%">'.
-	    '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/"><b>'.
-	    db_result($result,$i,'group_name') .'</b></a>';
-
-	  print '</td>'.
-	    '<td><a href="../my/rmproject.php?group_id='. db_result($result,$i,'group_id').
-	    '" onClick="return confirm(\''._("Quit this project?").'\')">'.
-	    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="remove"></a></td></tr>';
-	  $exists = 1;
-	  $j++;
-	}
-    }
-  print '</table>';
-
-  if (!$exists)
-    {
-      print _("You're not contributor member of any projects");
-    }
-  unset($exists);
-
-  print $HTML->box1_bottom();
-
-}
-
-
-
-# Change from the left to the right of the page
-print '</td><td valign="top" width="50%">';
-
-
-/*
-
-REQUEST FOR INCLUSION IN A GROUP
-
-*/
-
-print $HTML->box1_top(_("Request for Inclusion"));
-
-print '<h3>'._("Search a Group")."</h3>\n";
-print '<p>'._("If there is a group - or several - you want to be member of, to be able to fully contribute you can search his/their name(s) in the whole group database with the following search tool. A list of groups will be generated, depending on the word(s) you will type in this form.")."</p>\n";
+print '<div class="boxitem">'._("Search a Group")."\n";
+  print '<p class="text">';
+print _("If there is a project - or several - I would like to be member of, to be able to fully contribute, it is possible to search his/their name(s) in the whole group database with the following search tool. A list of groups will be generated, depending on the word(s) typed in this form.")."\n";
+print '</p>';
 
 print '
 	<form action="'.$PHP_SELF.'#searchgroup" method="post">
-	<input type="hidden" name="action" value="searchgroup">
-        <input type="text" size="35" name="words" value="'.$words.'"><br>
-	<p>
+	<input type="hidden" name="action" value="searchgroup" />
+        <input type="text" size="35" name="words" value="'.$words.'" /><br />
+	<br /><br />
 	<input type="submit" name="Submit" value="'
-	._("Search Group(s)").'">
+	._("Search Group(s)").'" />
 	</form>
-        <br>';
 
-print '</td></tr><tr><td class="boxitemalt">';
+</div><!-- end boxitem -->';
+
 
 if ($words)
 {
@@ -288,13 +189,14 @@ if ($words)
   else
     { $result_search = 0; }
 
-  print '<h3><a name="searchgroup"></a>'._("Requesting Inclusion").'</h3>';
-  print _("Below is the result of your search in the groups database.");
-  print '<br>';
+  print '<div class="boxitemalt"><a name="searchgroup"></a>'._("Requesting Inclusion");
+  print '<p class="text">';
+  print _("Below is the result of the research in the groups database.");
+  print '</p>';
 
   if (db_numrows($result_search) < 1)
     {
-      print '<br><font class="warn">'._("None found. Please note that only search words of more than three characters are valid.").'<br>';
+      print '<br /><font class="warn">'._("None found. Please note that only search words of more than three characters are valid.").'</font><br />';
     }
   else
     {
@@ -303,56 +205,58 @@ if ($words)
       # box or click on the link?).
       # This tool is to search groups for inclusion, not to look around
       # to get information about groups.
-      print _("To request inclusion in one or several groups, check the correspondants boxes, write a meaningful message for the project administrator, that will approve or disapprove your request, and submit the form.");
+      print '<p class="text">';
+      print _("To request inclusion in one or several groups, check the correspondants boxes, write a meaningful message for the project administrator, that will approve or disapprove the request, and submit the form.");
 
-      print '<br><br><form action="'.$PHP_SELF.'" method="post">';
+      print '<p/><form action="'.$PHP_SELF.'" method="post">';
 
       while ($val = db_fetch_array($result_search))
 	{
 	  if (!user_is_group_member($row_user[user_id], $val[group_id]))
 	    {
-	      print '<input type="checkbox" name="form_groups_'.$val[group_id].'"> ';
+	      print '<input type="checkbox" name="form_groups_'.$val[group_id].'" /> ';
 	      print $val[group_name];
-	      print '<br>';
+	      print '<br />';
 	    }
 	}
 
-      print '<p>'._("Comments (required):").'<br>
-     <textarea name="form_message" cols="40" rows="7"></textarea><br><br>
+      print '<br />'._("Comments (required):").'<br />
+     <textarea name="form_message" cols="40" rows="7"></textarea><br /><br />
      <input type="submit" name="update" value="';
-      print _("Request Inclusion").'"></form>';
+      print _("Request Inclusion").'" /></form>';
     }
+  print '</div><!-- end boxitemalt -->';
 }
 
 # If there was an error during registration, print out here
 if ($register_error)
 {
-  print "<p>$register_error";
+  print "<p>$register_error</p>";
 }
 
-print $HTML->box1_bottom();
-print '<br><br>';
+print $HTML->box_bottom(1);
+
+print "<br />\n";
 
 /*
      Projects the user requested to be member of
 */
 
-print $HTML->box1_top(_("Request for Inclusion Waiting For Approval"));
+print $HTML->box_top(_("Request for Inclusion Waiting For Approval"),'',1);
 
+unset($content);
 for ($i=0; $i<$rows; $i++)
 {
   if (db_result($result,$i,'admin_flags') == 'P')
     {
-      print '
-			       <table><tr class="'.utils_get_alt_row_color($i).'"><td width="99%">'.
-	'<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/"><b>'.
-	db_result($result,$i,'group_name') .'</b></a>';
+      
+      $content .= '<li class="'.utils_get_alt_row_color($j).'">';
+      $content .= '<span class="trash"><a href="../my/rmproject.php?group_id='. db_result($result,$i,'group_id').'">'.
+	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Discard this request?").'" /></a></span>'; 
 
-      print '</td>'.
-	'<td><a href="../my/rmproject.php?group_id='. db_result($result,$i,'group_id').
-	'" onClick="return confirm(\''._("Discard this request?").'\')">'.
-	'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="remove"></a></td></tr></table>';
+      $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />&nbsp;</li>';
       $exists=1;
+
     }
 }
 
@@ -360,12 +264,108 @@ if (!$exists)
 {
   print _("None Found");
 }
+else
+{
+  print '<ul class="boxli">'.$content.'</ul>';
+}
+unset($exists);
+
+print $HTML->box_bottom(1);
+
+print html_splitpage(2);
+
+################ LEFT PART ###########################
 
 
-print $HTML->box1_bottom();
+if (!$result || $rows < 1)
+{
+
+  print $HTML->box_top(_("My Groups"),'',1);
+  print _("You're not a member of any public projects");
+  print $HTML->box_bottom(1);
+
+}
+else
+{
+
+  /*
+     Projects administrated by the user
+  */
+
+  print $HTML->box_top(_("Groups I'm Administrator of"),'',1);
+
+  $j = 1;
+  unset($content);
+  for ($i=0; $i<$rows; $i++)
+    {
+      if (db_result($result,$i,'admin_flags') == 'A')
+	{
+	  $content .= '<li class="'.utils_get_alt_row_color($j).'">';
+	  $content .= '<span class="trash"><a href="../my/rmproject.php?group_id='. db_result($result,$i,'group_id').
+	    '">'.
+	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Quit this project?").'" /></a><br /></span>'; 
+
+	  $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />&nbsp;</li>';
+	  $exists=1;
+	  $j++;
+	}
+    }
+  if (!$exists)
+    {
+      print _("I am not administrator of any projects");
+    }
+  else
+    {
+      print '<ul class="boxli">'.$content.'</ul>';
+    }
+  unset($exists);
+  
+  print $HTML->box_bottom(1);
+
+  print "<br />\n";
+
+  /*
+     Projects the user is member of
+  */
+
+  print $HTML->box_top(_("Groups I'm Contributor of"),'',1);
+
+  $j = 1;
+  unset($content);
+  for ($i=0; $i<$rows; $i++)
+    {
+      if (db_result($result,$i,'admin_flags') == '')
+	{
+
+	  $content .= '<li class="'.utils_get_alt_row_color($j).'">';
+	  $content .= '<span class="trash"><a href="../my/rmproject.php?group_id='. db_result($result,$i,'group_id').
+	    '">'.
+	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Quit this project?").'" /></a></span>'; 
+
+	  $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />&nbsp;</li>';
+	  $exists=1;
+	  $j++;
+	}
+    }
+
+  if (!$exists)
+    {
+      print _("I am not contributor member of any projects");
+    }
+  else
+    {
+      print '<ul class="boxli">'.$content.'</ul>';
+    }
+  unset($exists);
+  
+  print $HTML->box_bottom(1);
+ 
+
+}
+
+print html_splitpage(3);
 
 
-print '</td></tr></table>';
 
 $HTML->footer(array());
 
