@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.17 2004/03/13 18:22:06 yeupou Exp $
+# $Id: index.php,v 1.18 2004/06/26 08:02:16 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2001 (c) Free Software Foundation
@@ -26,6 +26,23 @@
 
 require "../include/pre.php";
 
+if ($_POST['group_id'])
+   { 
+   $group_id = $_POST['group_id']; 
+   }
+elseif ($_GET['group_id'])
+   { 
+   $group_id = $_GET['group_id']; 
+   }
+if ($_POST['category_id'])
+   { 
+   $category_id = $_POST['category_id']; 
+   }
+elseif ($_GET['category_id'])
+   { 
+   $category_id = $_GET['category_id']; 
+   }
+   
 if ($group_id) 
 {
   
