@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: viewgpg.php,v 1.9 2004/03/13 18:22:06 yeupou Exp $
+# $Id: viewgpg.php,v 1.10 2004/06/08 14:54:12 zerodeux Exp $
 #
 #  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -53,7 +53,7 @@ if ($user_id)
 	} 
       else
 	{
-	  echo nl2br(utils_make_links(db_result($result,0,'gpg_key')));
+	  echo '<code>'.nl2br(utils_make_links(db_result($result,0,'gpg_key'))).'</code>';
 	}
     }
 
